SystemOrganization addCategory: #'OmniST-Tests-Languages-LRSTM'!
SystemOrganization addCategory: #'OmniST-Tests-Languages-Clojure'!
SystemOrganization addCategory: #'OmniST-Tests-Languages-AmbientTalk'!
SystemOrganization addCategory: #'OmniST-Tests-Languages-ActiveObject'!
SystemOrganization addCategory: #'OmniST-Tests-Languages-CSPi'!

TestCase subclass: #ATTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-AmbientTalk'!

!ATTests methodsFor: 'testing' stamp: 'StefanMarr 4/1/2012 10:28'!
execDomain
	^  OstDomain currentDomain! !

!ATTests methodsFor: 'testing' stamp: 'StefanMarr 1/10/2012 14:24'!
expectedFailures 
	(Smalltalk hasClassNamed: #ATFarReference) ifFalse: [
		^ #(testNewWithInitializerATST)
	].

	^ super expectedFailures! !

!ATTests methodsFor: 'testing' stamp: 'StefanMarr 4/1/2012 10:28'!
onBaselevel
	^ OstMirror executesOnBaseLevel! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 3/24/2012 11:08'!
testActorAndDomain
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ OstDomain currentDomain. 	].
	
	self assert: actor equals: p read.! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 4/1/2012 10:28'!
testActorAndDomainIndirect
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ self execDomain ].
	
	self assert: actor equals: p read.! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 3/24/2012 11:14'!
testEvaluateAsyncOmnified
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ OstMirror executesOnBaseLevel. ].
	
	self assert: p read.! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 4/1/2012 10:27'!
testEvaluateAsyncOmnifiedIndirect
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ self onBaselevel ].
	
	self assert: p read.! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 11:47'!
testNewWithInitializer
	"For the real AmbientTalk feeling"
	| result |
	result := ATActor newWithInitializer: [ATHelloWorld new].
	
	self assert: (result isKindOf: ATHelloWorld).
	! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/4/2012 14:12'!
testNewWithInitializerATST
	"For the real AmbientTalk feeling"
	| result |
	result := ATActor newWithInitializer: [ATHelloWorld new].
	
	self assert: (result isKindOf: ATHelloWorld).
	self assert: result class == (Smalltalk at: #ATFarReference).! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 3/22/2012 14:49'!
testNewWithInitializerOmni
	"For the real AmbientTalk feeling"
	| result domain |
	result := ATActor newWithInitializer: [ATHelloWorld new].
	
	self assert: (result isKindOf: ATHelloWorld) description: 'Result should be the blocks return value'.
	
	domain := OstMirror domainOf: result.
	self assert: domain notNil description: 'The domain of the ATHelloWorld object should have been properly initialized...'.
	self assert: (domain isKindOf: ATActor) description: '... to the ATActor object.'. ! !

TestCase subclass: #CSPiChannelTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-CSPi'!

!CSPiChannelTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 19:36'!
testConsecutiveSends
	| channel |
	channel := CSPiChannel new.

	[ channel in send: 1. ] fork.
	self assert: 1 equals: channel out receive.
	
	[ channel in send: 2. ] fork.
	self assert: 2 equals: channel out receive.
	
	[ channel in send: 3. ] fork.
	self assert: 3 equals: channel out receive.
	! !

!CSPiChannelTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 19:33'!
testCreateChannel
	| channel |
	channel := CSPiChannel new.

	[ channel in send: 1. ] fork. "Need to fork, is blocking operation"

	self assert: 1 equals: channel out receive.! !

TestCase subclass: #CSPiTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-CSPi'!

!CSPiTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 23:32'!
testBasicSetup
	
	| p1 p2 c1 c2 |
	
	p1 := CSPiPingPong newWith: #ping.
	p2 := CSPiPingPong newWith: #pong.
	
	c1 := CSPiChannel new.
	c2 := CSPiChannel new.
	
	p1 ping: c1 in.
	p1 pong: c2 out.
	
	p2 ping: c2 in.
	p2 pong: c1 out.
	
	p1 start.
	p2 start.
	
	p1 join.
	p2 join.! !

!CSPiTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 21:59'!
testIsolationAssign
	
	| proc obj |
	obj := CSPiTestSubject new.
	proc := CSPiPingPong newWith: obj.

	"Now the obj should be adopted"
	self should: [
		[obj a: #foo] omni.
		] raise: Error.
! !

!CSPiTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 21:58'!
testIsolationRead
	
	| proc obj |
	obj := CSPiTestSubject new.
	proc := CSPiPingPong newWith: obj.

	"Now the obj should be adopted"
	self should: [
		[obj a] omni.
		] raise: Error.
! !

!CSPiTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 21:59'!
testIsolationReflectiveRead
	
	| proc obj |
	obj := CSPiTestSubject new.
	proc := CSPiPingPong newWith: obj.

	"Now the obj should be adopted"
	self should: [
		[obj instVarAt: 1] omni.
		] raise: Error.
! !

!CSPiTest methodsFor: 'tests' stamp: 'StefanMarr 1/9/2012 21:59'!
testIsolationReflectiveWrite
	
	| proc obj |
	obj := CSPiTestSubject new.
	proc := CSPiPingPong newWith: obj.

	"Now the obj should be adopted"
	self should: [
		[obj instVarAt: 1 put: #foo] omni.
		] raise: Error.
! !

TestCase subclass: #LRSTMOmniTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMOmniTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/11/2011 22:51'!
testOmniDomain
	| domain |
	[ domain := OstDomain currentDomain. ] atomic.

	self deny: domain isNil.
	self assert: (domain isKindOf: LRSTMDomain).! !

TestCase subclass: #LRSTMTest
	instanceVariableNames: 'value array'
	classVariableNames: 'Value'
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

LRSTMTest subclass: #LRSTMAbortTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMAbortTest methodsFor: 'testing-abort' stamp: 'StefanMarr 11/30/2011 20:12'!
testAbortAccessor
	self assert: [ self value: true; abort: self value ] atomic.
	self assert: self value isNil! !

!LRSTMAbortTest methodsFor: 'testing-abort' stamp: 'lr 5/14/2007 09:11'!
testAbortInstance
	self assert: [ value := true. self abort: value ] atomic.
	self assert: value isNil! !

!LRSTMAbortTest methodsFor: 'testing-abort' stamp: 'lr 5/14/2007 09:12'!
testAbortLiteral
	self assert: [ Value := true. self abort: Value ] atomic.
	self assert: Value isNil! !

!LRSTMAbortTest methodsFor: 'testing-abort' stamp: 'lr 5/14/2007 09:12'!
testAbortTemp
	| temp |
	self assert: [ temp := true. self abort: temp ] atomic.
	self assert: temp! !

!LRSTMAbortTest methodsFor: 'testing-abort' stamp: 'lr 5/14/2007 09:12'!
testAbortVariable
	self assert: [ array at: 1 put: true. self abort: (array at: 1) ] atomic.
	self assert: (array at: 1) isNil! !

!LRSTMAbortTest methodsFor: 'testing-check' stamp: 'lr 6/8/2007 16:50'!
testCheckAccessor
	self assert: [ self value: true; checkpoint; abort: self value ] atomic.
	self assert: self value! !

!LRSTMAbortTest methodsFor: 'testing-check' stamp: 'lr 5/14/2007 09:13'!
testCheckInstance
	self assert: [ value := true. self checkpoint. self abort: value ] atomic.
	self assert: value! !

!LRSTMAbortTest methodsFor: 'testing-check' stamp: 'lr 5/14/2007 09:13'!
testCheckLiteral
	self assert: [ Value := true. self checkpoint. self abort: Value ] atomic.
	self assert: Value! !

!LRSTMAbortTest methodsFor: 'testing-check' stamp: 'lr 5/14/2007 09:13'!
testCheckTemp
	| temp |
	self assert: [ temp := true. self checkpoint. self abort: temp ] atomic.
	self assert: temp! !

!LRSTMAbortTest methodsFor: 'testing-check' stamp: 'lr 5/14/2007 09:13'!
testCheckVariable
	self assert: [ array at: 1 put: true. self checkpoint. self abort: (array at: 1) ] atomic.
	self assert: (array at: 1)! !

!LRSTMAbortTest methodsFor: 'testing-error' stamp: 'StefanMarr 4/15/2012 23:09'!
testErrorAccessor
	self 
		should: [ [ self value: true. self assert: self value. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: value isNil! !

!LRSTMAbortTest methodsFor: 'testing-error' stamp: 'lr 5/14/2007 08:39'!
testErrorInstance
	self 
		should: [ [ value := true. self assert: value. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: value isNil! !

!LRSTMAbortTest methodsFor: 'testing-error' stamp: 'lr 5/14/2007 08:39'!
testErrorLiteral
	self 
		should: [ [ Value := true. self assert: Value. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: Value isNil! !

!LRSTMAbortTest methodsFor: 'testing-error' stamp: 'lr 5/14/2007 08:43'!
testErrorTemp
	| temp |
	self 
		should: [ [ temp := true. self assert: temp. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: temp! !

!LRSTMAbortTest methodsFor: 'testing-error' stamp: 'lr 5/14/2007 08:39'!
testErrorVariable
	self 
		should: [ [ array at: 1 put: true. self assert: (array at: 1). 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: (array at: 1) isNil! !

LRSTMTest subclass: #LRSTMBasicTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:18'!
testAccessor
	self assert: [ self value: true. self value ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:18'!
testAccessorRead
	self value: true.
	self assert: [ self value ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:18'!
testAccessorWrite
	[ self value: true ] atomic.
	self assert: self value! !

!LRSTMBasicTest methodsFor: 'testing-basic' stamp: 'lr 5/9/2007 14:56'!
testBasicContext
	self assert: [ thisContext home ] atomic == thisContext! !

!LRSTMBasicTest methodsFor: 'testing-basic' stamp: 'lr 5/9/2007 11:18'!
testBasicSelf
	self assert: [ self ] atomic == self! !

!LRSTMBasicTest methodsFor: 'testing-basic' stamp: 'lr 5/9/2007 11:18'!
testBasicSuper
	self assert: [ super ] atomic == self! !

!LRSTMBasicTest methodsFor: 'testing-inheritance' stamp: 'StefanMarr 12/5/2011 11:35'!
testFieldReads
	| h |
	h := LRSTMHello3 new.
	self assert: #a equals: [h a] atomic.
	self assert: #b equals: [h b] atomic.
	self assert: #c equals: [h c] atomic.
	self assert: #d equals: [h d] atomic.
	self assert: #e equals: [h e] atomic.
	self assert: #f equals: [h f] atomic.! !

!LRSTMBasicTest methodsFor: 'testing-inheritance' stamp: 'StefanMarr 12/5/2011 11:37'!
testFieldReadsMixedInherited
	| h |
	h := LRSTMHello2 new.
	self assert: #a equals: [h a] atomic.
	self assert: #b equals: [h b] atomic.
	self assert: #c equals: [h c] atomic.
	self assert: #d equals: [h d] atomic.! !

!LRSTMBasicTest methodsFor: 'testing-inheritance' stamp: 'StefanMarr 12/5/2011 12:28'!
testFieldWrite
	| h |
	h := LRSTMHello3 new.
	
	[h a: #A] atomic.
	self assert: #A equals: [h a] atomic.
	
	[h b: #B] atomic.
	self assert: #B equals: [h b] atomic.
	
	[h c: #C] atomic.
	self assert: #C equals: [h c] atomic.
	
	[h d: #D] atomic.
	self assert: #D equals: [h d] atomic.
	
	[h e: #E] atomic.
	self assert: #E equals: [h e] atomic.
	
	[h f: #F] atomic.
	self assert: #F equals: [h f] atomic.! !

!LRSTMBasicTest methodsFor: 'testing-inheritance' stamp: 'StefanMarr 12/5/2011 12:30'!
testFieldWriteMixedInherited
	| h |
	h := LRSTMHello2 new.
	
	[h a: #A] atomic.
	self assert: #A equals: [h a] atomic.
	
	[h b: #B] atomic.
	self assert: #B equals: [h b] atomic.
	
	[h c: #C] atomic.
	self assert: #C equals: [h c] atomic.
	
	[h d: #D] atomic.
	self assert: #D equals: [h d] atomic.! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testGlobal
	self assert: [ GlobalValue := true. GlobalValue ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testGlobalRead
	GlobalValue := true.
	self assert: [ GlobalValue ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testGlobalWrite
	[ GlobalValue := true ] atomic.
	self assert: GlobalValue! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/9/2007 14:58'!
testInlinedAndOr
	self assert: [ true and: [ true ] ] atomic.
	self deny: [ false and: [ true ] ] atomic.
	self deny: [ true and: [ false ] ] atomic.
	self deny: [ false and: [ false ] ] atomic.

	self assert: [ true or: [ true ] ] atomic.
	self assert: [ false or: [ true ] ] atomic.
	self assert: [ true or: [ false ] ] atomic.
	self deny: [ false and: [ false ] ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/11/2007 15:07'!
testInlinedArray
	self assert: [ { } ] atomic = #( ).
	self assert: [ { 1 } ] atomic = #( 1 ).
	self assert: [ { 1. 2 } ] atomic = #( 1 2 ).
	self assert: [ { 1. 2. 3 } ] atomic = #( 1 2 3 ).
	self assert: [ { 1. 2. 3. 4 } ] atomic = #( 1 2 3 4 ).
	self assert: [ { 1. 2. 3. 4. 5 } ] atomic = #( 1 2 3 4 5 ).
	self assert: [ { 1. 2. 3. 4. 5. 6 } ] atomic = #( 1 2 3 4 5 6 )! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/11/2007 15:23'!
testInlinedArrayNested
	self assert: [ { { } } ] atomic = #( ( ) ).
	self assert: [ { { 1 } } ] atomic = #( ( 1 ) ).
	self assert: [ { { 1. 2 } } ] atomic = #( ( 1 2 ) ).
	self assert: [ { { 1. 2 }. { 3 } } ] atomic = #( ( 1 2 ) ( 3 ) ).
	self assert: [ { { 1. 2 }. { 3. 4 } } ] atomic = #( ( 1 2 ) ( 3 4 ) )! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/9/2007 14:58'!
testInlinedIfNil
	self assert: [ nil ifNil: [ true ] ] atomic.
	self assert: [ 1 ifNotNil: [ true ] ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/9/2007 14:58'!
testInlinedIfTrue
	self assert: [ true ifTrue: [ true ] ] atomic.
	self assert: [ false ifFalse: [ true ] ] atomic.
	self assert: [ true ifTrue: [ true ] ifFalse: [ false ] ] atomic.
	self assert: [ false ifFalse: [ true ] ifTrue: [ false ] ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/9/2007 11:42'!
testInlinedToDo
	| x |
	x := 0.
	[ 1 to: 10 do: [ :i | x := x + i ] ] atomic.
	self assert: x = 55.
	
	x := 0.
	[ 1 to: 10 by: 2 do: [ :i | x := x + i ] ] atomic.
	self assert: x = 25 ! !

!LRSTMBasicTest methodsFor: 'testing-inlined' stamp: 'lr 5/9/2007 15:14'!
testInlinedWhile
	| i x | 
	i := 1. x := 0.
	[ [ x := x + i. i := i + 1. i <= 10 ] whileTrue ] atomic.
	self assert: x = 55.
	
	i := 1. x := 0.
	[ [ i <= 10 ] whileTrue: [ x := x + i. i := i + 1 ] ] atomic.
	self assert: x = 55.
	
	i := 1. x := 0.
	[ [ x := x + i. i := i + 1. i > 10 ] whileFalse ] atomic.
	self assert: x = 55.
	
	i := 1. x := 0.
	[ [ i > 10 ] whileFalse: [ x := x + i. i := i + 1 ] ] atomic.
	self assert: x = 55! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testInstance
	self assert: [ value := true. value ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testInstanceRead
	value := true.
	self assert: [ value ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testInstanceWrite
	[ value := true ] atomic.
	self assert: value! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testLiteral
	self assert: [ Value := true. Value ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testLiteralRead
	Value := true.
	self assert: [ Value ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testLiteralWrite
	[ Value := true ] atomic.
	self assert: Value! !

!LRSTMBasicTest methodsFor: 'testing' stamp: 'lr 5/10/2007 09:48'!
testLoop
	"This code showed some bug in the exception handling."
	
 	| current |
	[ current := SortedCollection.
	[ current == nil ] whileFalse: [
		current == Object ifTrue: [ ^ self ].
		current := current superclass ] ]
			value.
	self assert: current == Object! !

!LRSTMBasicTest methodsFor: 'testing-sends' stamp: 'lr 5/9/2007 11:24'!
testSendBinary
	self assert: [ 1 + 2 ] atomic = 3! !

!LRSTMBasicTest methodsFor: 'testing-sends' stamp: 'lr 5/9/2007 11:24'!
testSendKeyword
	self assert: [ 2 raisedTo: 3 ] atomic = 8! !

!LRSTMBasicTest methodsFor: 'testing-sends' stamp: 'lr 5/9/2007 11:24'!
testSendUnary
	self assert: [ 1 negated ] atomic = -1! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testTemp
	| temp |
	self assert: [ temp := true. temp ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testTempRead
	| temp |
	temp := true.
	self assert: [ temp ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testTempWrite
	| temp |
	[ temp := true ] atomic.
	self assert: temp! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testVariable
	self assert: [ array at: 1 put: true; at: 1 ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testVariableRead
	array at: 1 put: true.
	self assert: [ array at: 1 ] atomic! !

!LRSTMBasicTest methodsFor: 'testing-kinds' stamp: 'lr 5/9/2007 11:19'!
testVariableWrite
	[ array at: 1 put: true ] atomic.
	self assert: (array at: 1)! !

LRSTMTest subclass: #LRSTMCUTransactionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMCUTransactionTest commentStamp: 'StefanMarr 11/28/2011 22:08' prior: 0!
This test suite is actually originating from the Cutie-Helvetia-Trans implementation.
It is ported back to the STM implementation Lukas Renggli implemented originally with Geppetto on Squeak 3.9!

!LRSTMCUTransactionTest methodsFor: 'testing-custom' stamp: 'StefanMarr 11/28/2011 22:25'!
conflict
	self transaction 
		addChange: (LRSTMCustomChange 
			onApply: [ value := true ]
			onConflictTest: [ true ])! !

!LRSTMCUTransactionTest methodsFor: 'testing-custom' stamp: 'StefanMarr 11/28/2011 22:21'!
sideeffect
	self transaction 
		addChange: (LRSTMCustomChange
			onApply: [ value := true ])! !

!LRSTMCUTransactionTest methodsFor: 'testing-abort' stamp: 'lr 2/23/2009 16:31'!
testAbortAccessor
	self assert: [ self value: true; abort: self value ] atomic.
	self assert: self value isNil! !

!LRSTMCUTransactionTest methodsFor: 'testing-abort' stamp: 'lr 2/23/2009 16:31'!
testAbortInstance
	self assert: [ value := true. self abort: value ] atomic.
	self assert: value isNil! !

!LRSTMCUTransactionTest methodsFor: 'testing-abort' stamp: 'lr 2/23/2009 16:31'!
testAbortTemp
	| temp |
	self assert: [ temp := true. self abort: temp ] atomic.
	self assert: temp! !

!LRSTMCUTransactionTest methodsFor: 'testing-kinds' stamp: 'lr 2/23/2009 16:31'!
testAccessor
	self assert: [ self value: true. self value ] atomic! !

!LRSTMCUTransactionTest methodsFor: 'testing-kinds' stamp: 'lr 2/23/2009 16:31'!
testAccessorRead
	self value: true.
	self assert: [ self value ] atomic! !

!LRSTMCUTransactionTest methodsFor: 'testing-kinds' stamp: 'lr 2/23/2009 16:31'!
testAccessorWrite
	[ self value: true ] atomic.
	self assert: self value! !

!LRSTMCUTransactionTest methodsFor: 'testing' stamp: 'lr 2/23/2009 16:31'!
testBasicContext
	self assert: [ thisContext home ] atomic == thisContext! !

!LRSTMCUTransactionTest methodsFor: 'testing' stamp: 'lr 2/23/2009 16:31'!
testBasicSelf
	self assert: [ self ] atomic == self! !

!LRSTMCUTransactionTest methodsFor: 'testing' stamp: 'lr 2/23/2009 16:31'!
testBasicSuper
	self assert: [ super ] atomic == self! !

!LRSTMCUTransactionTest methodsFor: 'testing-check' stamp: 'lr 2/23/2009 16:31'!
testCheckAccessor
	self assert: [ self value: true; checkpoint; abort: self value ] atomic.
	self assert: self value! !

!LRSTMCUTransactionTest methodsFor: 'testing-check' stamp: 'lr 2/23/2009 16:31'!
testCheckInstance
	self assert: [ value := true. self checkpoint. self abort: value ] atomic.
	self assert: value! !

!LRSTMCUTransactionTest methodsFor: 'testing-check' stamp: 'lr 2/23/2009 16:31'!
testCheckTemp
	| temp |
	self assert: [ temp := true. self checkpoint. self abort: temp ] atomic.
	self assert: temp! !

!LRSTMCUTransactionTest methodsFor: 'testing-custom' stamp: 'StefanMarr 11/28/2011 22:25'!
testConflict
	self 
		should: [ [ self conflict ] atomic ]
		raise: LRSTMConflict.
	self assert: value isNil! !

!LRSTMCUTransactionTest methodsFor: 'testing-error' stamp: 'lr 2/23/2009 16:31'!
testErrorAccessor
	self 
		should: [ [ self value: true. self assert: self value. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: value isNil! !

!LRSTMCUTransactionTest methodsFor: 'testing-error' stamp: 'lr 2/23/2009 16:31'!
testErrorInstance
	self 
		should: [ [ value := true. self assert: value. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: value isNil! !

!LRSTMCUTransactionTest methodsFor: 'testing-error' stamp: 'lr 2/23/2009 16:31'!
testErrorTemp
	| temp |
	self 
		should: [ [ temp := true. self assert: temp. 1 / 0 ] atomic ]
		raise: ZeroDivide.
	self assert: temp! !

!LRSTMCUTransactionTest methodsFor: 'testing-kinds' stamp: 'lr 2/23/2009 16:31'!
testInstance
	self assert: [ value := true. value ] atomic! !

!LRSTMCUTransactionTest methodsFor: 'testing-kinds' stamp: 'lr 2/23/2009 16:31'!
testInstanceRead
	value := true.
	self assert: [ value ] atomic! !

!LRSTMCUTransactionTest methodsFor: 'testing-kinds' stamp: 'lr 2/23/2009 16:31'!
testInstanceWrite
	[ value := true ] atomic.
	self assert: value! !

!LRSTMCUTransactionTest methodsFor: 'testing-custom' stamp: 'lr 2/23/2009 16:31'!
testSideeffect
	[ self sideeffect ] atomic.
	self assert: value! !

LRSTMTest subclass: #LRSTMCollectionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:04'!
testArrayLong
	| arr |
	arr := Array new: 10 withAll: 1.
	[ 3 to: 10 do: [ :each |
		arr at: each put: (arr at: each - 1) + (arr at: each - 2) ] ]
			atomic.
	3 to: 10 do: [ :each |
		self assert: (arr at: each) - (arr at: each - 1) = (arr at: each - 2) ]! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:04'!
testArrayShort
	| arr |
	arr := Array new: 10 withAll: 1.
	3 to: 10 do: [ :each |
		[ arr at: each put: (arr at: each - 1) + (arr at: each - 2) ]
			atomic ].
	3 to: 10 do: [ :each |
		self assert: (arr at: each) - (arr at: each - 1) = (arr at: each - 2) ]! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:04'!
testBagLong
	| bag |
	bag := Bag new.
	[ 1 to: 10 do: [ :each |
		bag add: each; add: each ] ]
			atomic.
	self assert: bag size = 20.
	1 to: 10 do: [ :each | 
		self assert: (bag occurrencesOf: each) = 2 ]! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/10/2007 14:19'!
testBagShort
	| bag |
	bag := Bag new.
	1 to: 10 do: [ :each |
		[ bag add: each; add: each ]
			atomic ].
	self assert: bag size = 20.
	1 to: 10 do: [ :each | 
		self assert: (bag occurrencesOf: each) = 2 ]! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:03'!
testDictionaryLong
	| dict |
	dict := Dictionary new.
	[ 1 to: 10 do: [ :each | 
		dict at: each put: each ] ]
			atomic.
	self assert: dict size = 10.
	1 to: 10 do: [ :each | 
		self assert: (dict at: each) = each ]! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:03'!
testDictionaryShort
	| dict |
	dict := Dictionary new.
	1 to: 10 do: [ :each | 
		[ dict at: each put: each ]
			atomic ].
	self assert: dict size = 10.
	1 to: 10 do: [ :each | 
		self assert: (dict at: each) = each ]! !

!LRSTMCollectionTest methodsFor: 'testing-streams' stamp: 'lr 5/14/2007 15:44'!
testReadStream
	| stream |
	stream := (1 to: 10) asArray readStream.
	[ 1 to: 10 do: [ :each | self assert: stream next = each ] ]
		atomic! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:04'!
testSetLong
	| set |
	set := Set new.
	[ 1 to: 10 do: [ :each | 
		set add: each ] ] 
			atomic.
	self assert: set size = 10.
	1 to: 10 do: [ :each | 
		self assert: (set includes: each) ]! !

!LRSTMCollectionTest methodsFor: 'testing' stamp: 'lr 5/9/2007 10:03'!
testSetShort
	| set |
	set := Set new.
	1 to: 10 do: [ :each |
		[ set add: each ]
			atomic ].
	self assert: set size = 10.
	1 to: 10 do: [ :each | 
		self assert: (set includes: each) ]! !

!LRSTMCollectionTest methodsFor: 'testing-streams' stamp: 'StefanMarr 4/22/2012 18:25'!
testStreamContents
	[RVMOperations breakpoint. 
	array := Array streamContents: [ :stream |
		1 to: 10 do: [ :each | 
			stream nextPut: each ] ].
	RVMOperations breakpoint.
	] atomic.
	self assert: (1 to: 10) asArray = array! !

!LRSTMCollectionTest methodsFor: 'testing-streams' stamp: 'lr 5/14/2007 15:45'!
testWriteStream
	| stream |
	stream := (Array new: 10) writeStream.
	[ 1 to: 10 do: [ :each | stream nextPut: each ] ]
		atomic.
	self assert: (1 to: 10) asArray = stream contents! !

LRSTMTest subclass: #LRSTMCustomTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMCustomTest methodsFor: 'actions' stamp: 'StefanMarr 12/11/2011 16:32'!
conflict
	<omniDoNotTransform>

	self transaction 
		addChange: (LRSTMCustomChange 
			onApply: [ value := true ]
			onConflictTest: [ true ])! !

!LRSTMCustomTest methodsFor: 'actions' stamp: 'StefanMarr 12/11/2011 16:35'!
sideeffect
	<omniDoNotTransform>

	self transaction 
		addChange: (LRSTMCustomChange onApply: [ value := true ])! !

!LRSTMCustomTest methodsFor: 'testing' stamp: 'lr 2/26/2008 16:22'!
testConflict
	self 
		should: [ [ self conflict ] atomic ]
		raise: LRSTMConflict.
	self assert: value isNil! !

!LRSTMCustomTest methodsFor: 'testing' stamp: 'lr 2/26/2008 16:23'!
testSideeffect
	[ self sideeffect ] atomic.
	self assert: value! !

LRSTMTest subclass: #LRSTMNestedTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMNestedTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/10/2012 11:45'!
expectedFailures
	^ #(testAbortInner) "STEFAN: 2012-01-10 did not work in the original 3.9 image built from Lukas repo either..."! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 18:46'!
testAbortInner
	self assert: [ value := true. [ value := false. self abort: value ] atomic. value ] atomic.
	self assert: value! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 18:50'!
testAbortOuter
	self assert: [ [ value := true ] atomic. self abort: value ] atomic.
	self assert: value isNil! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 16:54'!
testEmpty
	[ [ ] atomic ] atomic! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 18:46'!
testKind
	self assert: [ self transaction ] atomic isNested not.
	self assert: [ [ self transaction ] atomic ] atomic isNested.
	self assert: [ [ [ self transaction ] atomic ] atomic ] atomic isNested.
	
	self assert: [ [ ] atomic. self transaction ] atomic isNested not.! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 16:54'!
testSimple
	[ [ value := true ] atomic ] atomic.
	self assert: value! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 18:24'!
testValueInner
	self assert: [ value := true. [ value ] atomic ] atomic.
	self assert: value! !

!LRSTMNestedTest methodsFor: 'testing' stamp: 'lr 2/26/2008 18:24'!
testValueOuter
	self assert: [ [ value := true ] atomic. value ] atomic.
	self assert: value! !

!LRSTMTest class methodsFor: 'initialization' stamp: 'lr 5/4/2007 14:37'!
initialize
	self environment at: #GlobalValue put: nil! !

!LRSTMTest class methodsFor: 'testing' stamp: 'lr 2/26/2008 16:27'!
isAbstract
	^ self name = #LRSTMTest! !

!LRSTMTest methodsFor: 'utilities' stamp: 'StefanMarr 12/11/2011 16:28'!
abort: anObject
	<omniDoNotTransform>

	self transaction abort: anObject! !

!LRSTMTest methodsFor: 'utilities' stamp: 'StefanMarr 12/11/2011 16:32'!
checkpoint
	<omniDoNotTransform>

	self transaction checkpoint! !

!LRSTMTest methodsFor: 'running' stamp: 'StefanMarr 4/22/2012 17:34'!
setUp
	value := nil.
	array := Array new: 1.
	Value := nil.
	GlobalValue := nil.
	
	LRSTMDomain domain adoptObject: self.
	LRSTMDomain domain adoptObject: array.! !

!LRSTMTest methodsFor: 'running' stamp: 'lr 2/26/2008 18:30'!
tearDown
	Processor activeProcess currentTransaction: nil! !

!LRSTMTest methodsFor: 'utilities' stamp: 'StefanMarr 12/11/2011 16:35'!
transaction
	<omniDoNotTransform>

	^ Processor activeProcess currentTransaction! !

!LRSTMTest methodsFor: 'accessing' stamp: 'lr 5/3/2007 15:59'!
value
	^ value! !

!LRSTMTest methodsFor: 'accessing' stamp: 'lr 6/8/2007 16:52'!
value: anObject
	value := anObject! !

TestCase subclass: #OActiveObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-ActiveObject'!

!OActiveObjectTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:49'!
testActiveObjectReturnsPromise
	| ao result |
	ao := OActiveObjectTestSubject new.

	self assert: nil equals: ao a.
	
	result := [ao a: #foo] omni.
	self assert: (result isKindOf: OPromise).
	
	result := [ao a] omni.
	self assert: (result isKindOf: OPromise).
	
	result := [ao b: #foo] omni.
	self assert: (result isKindOf: OPromise).! !

!OActiveObjectTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 18:30'!
testCheckAsyncExecution
	| ao |
	ao := OActiveObjectTestSubject new.

	self assert: nil equals: ao a.
	
	"Foo should not be executed imediatly."
	[| p |
	 p := [ao a: #foo] omni.
	 self assert: (p isKindOf: OPromise).
	 self assert: nil equals: ao a.
	] valueUnpreemptively.

	Processor yield. "This works only since we assume round-robin scheduling"
	Processor yield.
	
	self assert: #foo equals: ao a.! !

!OActiveObjectTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 18:28'!
testCheckAsyncExecutionOfReflection
	| ao idxA |
	ao := OActiveObjectTestSubject new.
	idxA := OActiveObjectTestSubject instVarIndexFor: #a.
	
	
	self assert: nil equals: ao a.
	
	"Foo should not be executed imediatly."
	[[ao instVarNamed: #a put: #foo] omni.
	 self assert: nil equals: ao a.
	] valueUnpreemptively.

	Processor yield. "This works only since we assume round-robin scheduling"
	(Delay forSeconds: 1) wait.
	
	self assert: #foo equals: ao a.! !

!OActiveObjectTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:53'!
testCheckSyncExecutionOnPassiveObjects
	| ao passive result |
	ao := OActiveObjectTestSubject new.
	
	[ passive := ao somePassiveObj read] omni.

	self assert: nil equals: passive a.
	
	"Is directly executed without sending an async message."
	[[ passive a: #foo ] omni.
	 self assert: #foo equals: passive a.
	] valueUnpreemptively.
! !

OActiveObject subclass: #OActiveObjectTestSubject
	instanceVariableNames: 'a b'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-ActiveObject'!

!OActiveObjectTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 15:53'!
a
	^ a! !

!OActiveObjectTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 15:53'!
a: anA
	a := anA! !

!OActiveObjectTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 15:53'!
b
	^ b! !

!OActiveObjectTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 15:53'!
b: aB
	b := aB! !

!OActiveObjectTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:53'!
somePassiveObj
	^ OActiveObjectTestSubject2 new.! !

OActiveObject subclass: #OpAOPingPong
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-ActiveObject'!

!OpAOPingPong class methodsFor: 'as yet unclassified' stamp: 'StefanMarr 11/6/2011 00:47'!
example
	[ | ping |
		ping := OpAOPingPong new.
		ping ping. ] forkNamed: 'ping-pong-test'.! !

!OpAOPingPong methodsFor: 'as yet unclassified' stamp: 'StefanMarr 3/22/2012 14:46'!
ping
	<noReturnValue>
	Transcript log: 'ping'.
	Transcript log: 'PingPong domain: ', 
						(OstMirror domainOf: self) printString, '(', (OstMirror domainOf: self) hash asString, ')'.
	
	OpAOPingObj new printDomain.
	
	self pong.
	! !

!OpAOPingPong methodsFor: 'as yet unclassified' stamp: 'StefanMarr 11/5/2011 23:26'!
pong
	<noReturnValue>
	Transcript addEntry: 'pong'.! !

CSPiProcess subclass: #CSPiPingPong
	instanceVariableNames: 'role inputEnd receivingEnd'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-CSPi'!

!CSPiPingPong class methodsFor: 'VM support' stamp: 'StefanMarr 4/23/2012 15:43'!
domainCustomizations ^ 16r2018010! !

!CSPiPingPong class methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 23:55'!
newWith: pingOrPong
	| proc |
	proc := self new.
	proc role: pingOrPong.
	proc adoptObject: pingOrPong.
	^ proc.! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 1/9/2012 23:16'!
ping: anInputEnd
	inputEnd := anInputEnd! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 1/9/2012 23:17'!
pong: aReceivingEnd
	receivingEnd := aReceivingEnd! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 3/31/2012 18:32'!
receivePing
	| val |
	ScriptConsole println: role asString, ': receivePing'.
	val := receivingEnd receive.
	
	ScriptConsole println: role asString, ': receivePing completed.'.
	
	val = #ping ifFalse: [Error signal: 'Did not receive a ping but a ', val asString].! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 3/31/2012 18:32'!
receivePong
	| val |
	ScriptConsole println: role asString, ': receivePong.'.
	
	val := receivingEnd receive.
	
	ScriptConsole println: role asString, ': receivePong completed.'.
	
	val = #pong ifFalse: [Error signal: 'Did not receive a pong but a ', val asString].! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 1/9/2012 23:01'!
role: pingOrPong
	role := pingOrPong! !

!CSPiPingPong methodsFor: 'process runnable' stamp: 'StefanMarr 1/9/2012 23:20'!
run
	role = #ping
		ifTrue: [
			self sendPing.
			self receivePong.
		]
		ifFalse: [
			self receivePing.
			self sendPong.
		]! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 3/31/2012 20:26'!
sendPing
	ScriptConsole println: role asString, ': sendPing'.
	inputEnd send: #ping.
	ScriptConsole println: role asString, ': sendPing done'.! !

!CSPiPingPong methodsFor: 'ping pong' stamp: 'StefanMarr 3/31/2012 18:32'!
sendPong
	ScriptConsole println: role asString, ': sendPong'.
	inputEnd send: #pong.! !

ATActor subclass: #ATTracingActor
	instanceVariableNames: 'cnt msgTrace'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-AmbientTalk'!

!ATTracingActor class methodsFor: 'VM support' stamp: 'StefanMarr 4/23/2012 15:43'!
domainCustomizations ^ 16r33F8010! !

!ATTracingActor methodsFor: 'initialization' stamp: 'StefanMarr 1/4/2012 14:56'!
initialize
	cnt := 0.
	msgTrace := OrderedCollection new.
	
	super initialize.! !

!ATTracingActor methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 23:54'!
numberOfProcessedMessages
	^ cnt! !

!ATTracingActor methodsFor: 'actor semantics' stamp: 'StefanMarr 3/31/2012 15:59'!
processIncomingMessages
	| msg result |
	<omniMetaExit>
	msg := mailbox next.
	
	result := msg send.
	
	msgTrace addLast: msg selector.
	cnt := cnt + 1.
	
	msg result: result.
	! !

OstObject subclass: #CSPiTestSubject
	instanceVariableNames: 'a'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-CSPi'!

!CSPiTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 21:54'!
a
	^ a! !

!CSPiTestSubject methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 21:55'!
a: anA
	a := anA! !

OstObject subclass: #OActiveObjectTestSubject2
	instanceVariableNames: 'a b'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-ActiveObject'!

!OActiveObjectTestSubject2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:42'!
a
	^ a! !

!OActiveObjectTestSubject2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:43'!
a: anA
	a := anA! !

!OActiveObjectTestSubject2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:42'!
b
	^ b! !

!OActiveObjectTestSubject2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/9/2012 16:42'!
b: aB
	b := aB! !

OstObject subclass: #OcjAgentTestSuject
	instanceVariableNames: 'a b'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-Clojure'!

!OcjAgentTestSuject methodsFor: 'accessing' stamp: 'StefanMarr 1/6/2012 14:58'!
a
	^ a! !

!OcjAgentTestSuject methodsFor: 'accessing' stamp: 'StefanMarr 1/6/2012 14:58'!
a: aVal
	a := aVal! !

!OcjAgentTestSuject methodsFor: 'accessing' stamp: 'StefanMarr 1/6/2012 14:58'!
b
	^ b! !

!OcjAgentTestSuject methodsFor: 'accessing' stamp: 'StefanMarr 1/6/2012 14:58'!
b: aVal
	b := aVal! !

!OcjAgentTestSuject methodsFor: 'initialization' stamp: 'StefanMarr 1/6/2012 14:58'!
initialize
	a := #a.
	b := #b.! !

Object subclass: #LRSTMHello
	instanceVariableNames: 'a b'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMHello class methodsFor: 'as yet unclassified' stamp: 'StefanMarr 11/29/2011 01:12'!
example
	|  p1 p2 hello |
	hello := self new.
	
	"Since this main thread is not running inside the OPSTMDomain, which would be easy, too,
	 but is not happening here, we need to manually move the object into the domain."
	
	hello a: 'main'; b: 'main'.
	
	p1 := [
		1 halt.
		[	hello a: 'p1'.
			Processor yield.
			hello b: 'p1'.] atomic
	] fork.

	p2 := [
		[	| b |
			b := hello b.
			Processor yield.
			hello b: 'p2'.] atomic
	] fork.! !

!LRSTMHello methodsFor: 'as yet unclassified' stamp: 'StefanMarr 11/29/2011 01:11'!
a
	^ a asString! !

!LRSTMHello methodsFor: 'as yet unclassified' stamp: 'StefanMarr 11/29/2011 01:12'!
a: obj
	a := obj asString! !

!LRSTMHello methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 16:54'!
b
	^ b asString! !

!LRSTMHello methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 16:54'!
b: obj
	b := obj asString! !

!LRSTMHello methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:34'!
initialize
	super initialize.
	a := #a.
	b := #b.! !

LRSTMHello subclass: #LRSTMHello2
	instanceVariableNames: 'c d'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMHello2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
c
	^ c! !

!LRSTMHello2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:29'!
c: v
	c := v! !

!LRSTMHello2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
d
	^ d! !

!LRSTMHello2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:29'!
d: v
	d := v! !

!LRSTMHello2 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:33'!
initialize
	super initialize.
	c := #c.
	d := #d.! !

LRSTMHello2 subclass: #LRSTMHello3
	instanceVariableNames: 'e f'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-LRSTM'!

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
a
	^ a! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:28'!
a: v
	a := v! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
b
	^ b! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:28'!
b: v
	b := v! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
c
	^ c! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:28'!
c: v
	c := v! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
d
	^ d! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:28'!
d: v
	d := v! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
e
	^ e! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:28'!
e: v
	e := v! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:36'!
f
	^ f! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 12:28'!
f: v
	f := v! !

!LRSTMHello3 methodsFor: 'as yet unclassified' stamp: 'StefanMarr 12/5/2011 11:33'!
initialize
	super initialize.
	e := #e.
	f := #f.! !

Object subclass: #OpAOPingObj
	instanceVariableNames: 'omniDomain'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-ActiveObject'!

!OpAOPingObj methodsFor: 'as yet unclassified' stamp: 'StefanMarr 11/6/2011 19:59'!
printDomain
	Transcript log: omniDomain printString, '(', omniDomain hash asString, ')'.! !

CjAgentTest subclass: #OcjAgentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-Clojure'!

!OcjAgentTest class methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/6/2012 13:01'!
shouldInheritSelectors
	^ true! !

!OcjAgentTest methodsFor: 'configuration' stamp: 'StefanMarr 1/5/2012 14:26'!
agentNew
	^ OcjAgent new! !

!OcjAgentTest methodsFor: 'configuration' stamp: 'StefanMarr 1/5/2012 14:26'!
agentNew: initialState
	^ OcjAgent new: initialState! !

!OcjAgentTest methodsFor: 'tests' stamp: 'StefanMarr 1/6/2012 12:48'!
testAwaitOmni
	| agent |
	agent := self agentNew.

	[ agent send: [:i | #noop].
	  agent send: [:i | #noop].
	  agent send: [:i | #noop].
	  agent send: [:i | #last].
	
	  agent await. ] omni. "The agent is its own domain, and we access it from another domain."
	
	self assert: #last equals: agent read.
	! !

!OcjAgentTest methodsFor: 'tests' stamp: 'StefanMarr 1/6/2012 12:49'!
testReadOmni
	| agent result |
	
	"without initial value"
	agent := self agentNew.
	self assert: nil    equals: [ agent read ] omni.
	
	"with initial value"
	agent := self agentNew: #first.
	self assert: #first equals: [ agent read ] omni.
	
	result := [
		agent send: [:i | #foo].
		agent await.
		agent read ] omni.
	self assert: #foo equals: result.! !

!OcjAgentTest methodsFor: 'tests' stamp: 'StefanMarr 1/6/2012 14:35'!
testSendOmni
	| agent result |
	agent := self agentNew: 0.
	
	self assert: 0 equals: agent read.

	result := [
		agent send: [:old | old + 1].
		agent await.
		agent read. ] omni.
	
	self assert: 1 equals: result.
	
	result := [
		agent send: [:old | old + 20].
		agent send: [:old | old + 21].
		agent await.
		agent read ] omni.
	
	self assert: 42 equals: result.
	! !

!OcjAgentTest methodsFor: 'tests' stamp: 'StefanMarr 1/6/2012 12:58'!
testSendWithOmni
	| agent incFn result |
	agent := self agentNew: 0.
	
	result := [
		incFn := [:old :inc | old + inc]. "make sure this block is omnified"
		agent read. ] omni.
	
	self assert: 0 equals: result.
	
	result := [
		agent send: incFn with: 1.
		agent await.
		agent read ] omni.
	
	self assert: 1 equals: result.
	
	result := [
		agent send: incFn with: 20.
		agent send: incFn with: 21.
		agent await.
		agent read ] omni.
	
	self assert: 42 equals: result.! !

OcjAgentTest subclass: #OcjAgentWithImmutabilityTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniST-Tests-Languages-Clojure'!

!OcjAgentWithImmutabilityTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/6/2012 15:22'!
testImmutabilityOk
	| agent a b |
	agent := OcjAgentWithImmutability new.
	
	[ | r |
	  agent send: [:o| OcjAgentTestSuject new.].
	  agent await.
	  r := agent read.
	  a := r a.
	  b := r b. ] omni.

	self assert: #a equals: a.
	self assert: #b equals: b.! !

!OcjAgentWithImmutabilityTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/6/2012 15:30'!
testImmutabilityOkWithUseInOmniDomain
	| agent a b |
	agent := OcjAgentWithImmutability new.
	
	[ | r |
	  agent send: [:o| OcjAgentTestSuject new.].
	  agent await.
	  r := agent read.
	  a := r a.
	  b := r b. ] omni.

	self assert: #a equals: a.
	self assert: #b equals: b.
	
	[ agent send: [:o | | n |
							n := OcjAgentTestSuject new.
							n a: o.
							n].
	  agent await.
	  a := agent read] omni.

	self assert: #a equals: a a a.! !

!OcjAgentWithImmutabilityTest methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/6/2012 15:29'!
testImmutabilityViolation
	| agent a b |
	agent := OcjAgentWithImmutability new.
	
	[ agent send: [:o| OcjAgentTestSuject new.] ] omni.
	
	agent await.
	a := agent read.
	
	self should: [ [ a a: #foo.] omni.]
	     raise:  Error.

	self assert: #a equals: a a.! !
LRSTMTest initialize!
